( cd usr/lib ; rm -rf libgnashbase.so )
( cd usr/lib ; ln -sf libgnashbase-0.7.2.so libgnashbase.so )
( cd usr/lib ; rm -rf libgnashgeo.so )
( cd usr/lib ; ln -sf libgnashgeo-0.7.2.so libgnashgeo.so )
( cd usr/lib ; rm -rf libgnashamf.so )
( cd usr/lib ; ln -sf libgnashamf-0.7.2.so libgnashamf.so )
( cd usr/lib ; rm -rf libgnashserver.so )
( cd usr/lib ; ln -sf libgnashserver-0.7.2.so libgnashserver.so )
( cd usr/lib ; rm -rf libgnashbackend.so )
( cd usr/lib ; ln -sf libgnashbackend-0.7.2.so libgnashbackend.so )
( cd usr/lib ; rm -rf libgnashgui.so )
( cd usr/lib ; ln -sf libgnashgui-0.7.2.so libgnashgui.so )
